==> myfaces-tobago-1.5.13-dist.zip: org/apache/myfaces/tobago/internal/taglib/component/SeparatorTagDeclaration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.taglib.component;

import org.apache.myfaces.tobago.apt.annotation.Facet;
import org.apache.myfaces.tobago.apt.annotation.Tag;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTag;
import org.apache.myfaces.tobago.component.Facets;
import org.apache.myfaces.tobago.component.RendererTypes;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasCurrentMarkup;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasIdBindingAndRendered;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasLabel;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasMarkup;
import org.apache.myfaces.tobago.internal.taglib.declaration.IsGridLayoutComponent;

/**
 * Renders a separator.
 */
@Tag(name = "separator")
@UIComponentTag(rendererType = RendererTypes.SEPARATOR,
    uiComponent = "org.apache.myfaces.tobago.component.UISeparator",
    uiComponentBaseClass = "org.apache.myfaces.tobago.internal.component.AbstractUISeparator",
    componentFamily = "org.apache.myfaces.tobago.Separator",
    componentType = "org.apache.myfaces.tobago.Separator",
    allowedChildComponenents = "NONE",
    facets = {
        @Facet(name = Facets.LABEL,
            description = "This facet contains a UILabel",
            allowedChildComponenents = "org.apache.myfaces.tobago.Label")})

public interface SeparatorTagDeclaration
    extends HasIdBindingAndRendered, IsGridLayoutComponent, HasLabel, HasMarkup, HasCurrentMarkup {
}

==> myfaces-tobago-2.5.2-dist.zip: org/apache/myfaces/tobago/internal/taglib/component/SeparatorTagDeclaration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.taglib.component;

import org.apache.myfaces.tobago.apt.annotation.Facet;
import org.apache.myfaces.tobago.apt.annotation.Tag;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTag;
import org.apache.myfaces.tobago.component.Facets;
import org.apache.myfaces.tobago.component.RendererTypes;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasCurrentMarkup;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasIdBindingAndRendered;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasLabel;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasMarkup;
import org.apache.myfaces.tobago.internal.taglib.declaration.IsGridLayoutComponent;

/**
 * Renders a separator.
 */
@Tag(name = "separator")
@UIComponentTag(
    uiComponent = "org.apache.myfaces.tobago.component.UISeparator",
    uiComponentBaseClass = "org.apache.myfaces.tobago.internal.component.AbstractUISeparator",
    uiComponentFacesClass = "javax.faces.component.UIComponentBase",
    componentFamily = "org.apache.myfaces.tobago.Separator",
    rendererType = RendererTypes.SEPARATOR,
    allowedChildComponenents = "NONE",
    facets = {
        @Facet(name = Facets.LABEL,
            description = "This facet contains a UILabel",
            allowedChildComponenents = "org.apache.myfaces.tobago.Label")})

public interface SeparatorTagDeclaration
    extends HasIdBindingAndRendered, IsGridLayoutComponent, HasLabel, HasMarkup, HasCurrentMarkup {
}
